/* This file is part of PolyCalc.

   PolyCalc is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   any later version.

   PolyCalc is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PolyCalc.  If not, see <http://www.gnu.org/licenses/>.

   For more information about PolyCalc see project home
   <https://launchpad.net/polycalc>.

   Copyright 2012 PolyCalc development team */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QGridLayout>
#include <QPushButton>
#include <QLabel>
#include <QProcess>
#include <QSettings>
#include <QList>
#include <QtXml>
#include <QSignalMapper>
#include <QtScript>


namespace Ui {
class MainWindow;
}

enum eEngineType { eEngTypeQtScript, eEngTypeExternal };

class MainWindow : public QMainWindow
{
    Q_OBJECT
    
public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();
    
private:
    Ui::MainWindow *ui;
    QGridLayout *mainLayout;
    QSettings *settings;
    QSignalMapper *buttonSignalMapper;
    QSignalMapper *menuSignalMapper;
    enum eEngineType engineType;
    QScriptEngine *scriptEngine;
    QProcess      *externalEngine;
    QScriptEngine *stringPipeEngine;
    QString statusbarScript;
    QList<QLabel*> labels;
    void setStatusBarText(QString error);
    void PopulateButtons(QString filename);
    void PopulateMenu();
    void deleteGrid(QLayout *grid);
    QGridLayout *XMLGridNodeToQGridLayout(QDomNode *grid, QString parentStyle);
    void resizeEvent(QResizeEvent *event);
    void updateLabels(void);

private slots:
    void on_anyButtonClicked(QObject *);
    void loadLayout(const QString &);
    void on_lineEdit_returnPressed(void);
    void on_actionQuit_triggered();
    void on_actionAbout_triggered();
    void on_actionHelp_triggered();
    void on_actionCommand_Log_triggered();
    void on_extEngStdErr();
    void on_extEngStdOut();
};

#endif // MAINWINDOW_H
